﻿using C1.Win.FlexGrid;
using System.Diagnostics;

namespace FlexGrid_QuickStart.CustomeFilters
{
    public class CustomColumnFilterEditor : ColumnFilterEditor {
        #region Members
        CustomColumnFilter customFilter;
        private CheckBox chkSO;
        private CheckBox chkSA;
        private CheckBox chkFR;
        private CheckBox chkTH;
        private CheckBox chkWED;
        private CheckBox chkTU;
        private CheckBox chkMO;
        #endregion

        #region C'tor
        public CustomColumnFilterEditor()
        {
            this.Width = 250;
            //Enable Composed Menu
            this.UseComposedMenu = true;

            //Add custom filter menu item in MenuFilters
            var columnFilterMenuItem = new ColumnFilterMenuItem() { Text = "Day Filter" };
            columnFilterMenuItem.Click += ColumnFilterMenuItem_Click; 
            MenuFilters.DropDownItems.Add(columnFilterMenuItem);
            MenuFilters.Enabled = true;

            this.ActiveEditorChanged += CustomColumnFilterEditor_ActiveEditorChanged;
            MenuFilters.DropDownItems[1].Click += DefaultFilter_Click;
            MenuFilters.DropDownItems[0].Click += DefaultFilter_Click;
        }
        #endregion

        #region Event Handlers
        private void DefaultFilter_Click(object? sender, EventArgs e)
        {
            //Default Filter
            customFilter.IsFilterDefault = true;
        }

        private void ColumnFilterMenuItem_Click(object? sender, EventArgs e)
        {
            //Custom Filter
            if (sender is ColumnFilterMenuItem menuItem)
            {
                menuItem.Highlighted = true;
                customFilter.IsFilterDefault = false;                
                ActiveEditor = this;
            }            
        }

        private void CustomColumnFilterEditor_ActiveEditorChanged(object? sender, EventArgs e)
        {
            Debug.WriteLine("Active Editor Changed");
        }
        #endregion

        #region Overridden
        public override IC1ColumnFilterEditor ActiveEditor { get => base.ActiveEditor   ; set => base.ActiveEditor = value; }

        public override void ApplyChanges()
        {
            if(customFilter.IsFilterDefault)
            {
                //Apply Filter for default filters
                base.ApplyChanges();
            }
            else
            {
                //Apply Filter
                this.customFilter.Reset();
                this.customFilter.Monday = this.chkMO.Checked;
                this.customFilter.Tuesday = this.chkTU.Checked;
                this.customFilter.Wednesday = this.chkWED.Checked;
                this.customFilter.Thursday = this.chkTH.Checked;
                this.customFilter.Friday = this.chkFR.Checked;
                this.customFilter.Saturday = this.chkSA.Checked;
                this.customFilter.Sunday = this.chkSO.Checked;
            }
        }
        public override void Initialize(C1FlexGridBase grid, int columnIndex, IC1ColumnFilter filter)
        {
            // Create custom Filter Editor(UI)
            var panel = new Panel() { Height = 150 };
            var s = Filter;
            this.customFilter = (CustomColumnFilter)filter;
            this.customFilter.IsFilterDefault = true;
            this.chkSO = new CheckBox() { Text = "Sunday", Size = new Size(90, 20), Location = new Point(5, 5) };
            this.chkMO = new CheckBox() { Text = "Monday", Size = new Size(90, 20), Location = new Point(5, 25) };
            this.chkTU = new CheckBox() { Text = "Tuesday", Size = new Size(90, 20), Location = new Point(5, 45) };
            this.chkWED = new CheckBox() { Text = "Wednesday", Size = new Size(90, 20), Location = new Point(5, 65) };
            this.chkTH = new CheckBox() { Text = "Thursday", Size = new Size(90, 20), Location = new Point(5, 85) };
            this.chkFR = new CheckBox() { Text = "Friday", Size = new Size(90, 20), Location = new Point(5, 105) };
            this.chkSA = new CheckBox() { Text = "Saturday", Size = new Size(90, 20), Location = new Point(5, 125) };
            panel.Controls.Add(this.chkSO);
            panel.Controls.Add(this.chkSA);
            panel.Controls.Add(this.chkFR);
            panel.Controls.Add(this.chkTH);
            panel.Controls.Add(this.chkWED);
            panel.Controls.Add(this.chkTU);
            panel.Controls.Add(this.chkMO);
            this.Controls.Add(panel);

            this.chkMO.Checked = this.customFilter.Monday;
            this.chkTU.Checked = this.customFilter.Tuesday;
            this.chkWED.Checked = this.customFilter.Wednesday;
            this.chkTH.Checked = this.customFilter.Thursday;
            this.chkFR.Checked = this.customFilter.Friday;
            this.chkSA.Checked = this.customFilter.Saturday;
            this.chkSO.Checked = this.customFilter.Sunday;

            //Initialize the default filter
            base.Initialize(grid, columnIndex, this.customFilter.FilterDefault);
        }
        #endregion
        private void InitializeComponent()
        {
            this.SuspendLayout();
            // 
            // ValueFilterEditor
            // 
            this.ValueFilterEditor.Size = new System.Drawing.Size(378, 129);
            // 
            // CustomColumnFilterEditor
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(96F, 96F);
            this.Name = "CustomColumnFilterEditor";
            this.ResumeLayout(false);
            this.PerformLayout();

        }
    }
}
